==> qmmp-0.8.0.tar.bz2: qmmp-0.8.0/src/plugins/General/udisks/translations/udisks_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Nastavení modulu UDisks</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Detekce zvukových CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Automaticky přidat stopy do seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Automaticky odebrat stopy ze seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Detekce odpojitelných zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Automaticky přidat soubory do seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Automaticky odebrat stopy ze seznamu skladeb</translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="30"/>
        <source>UDisks Plugin</source>
        <translation>Modul UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="50"/>
        <source>About UDisks Plugin</source>
        <translation>O modulu UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>Qmmp UDisks Plugin</source>
        <translation>Modul Qmmp UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation>Tento modul poskytuje detekci výměnných médií pomocí UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Přidat CD „%1“</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Přidat svazek „%1“</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/General/udisks/translations/udisks_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Nastavení modulu UDisks</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Detekce zvukových CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Automaticky přidat stopy do seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Automaticky odebrat stopy ze seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Detekce odpojitelných zařízení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Automaticky přidat soubory do seznamu skladeb</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Automaticky odebrat stopy ze seznamu skladeb</translation>
    </message>
</context>
<context>
    <name>UDisksFactory</name>
    <message>
        <location filename="../udisksfactory.cpp" line="31"/>
        <source>UDisks Plugin</source>
        <translation>Modul UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="51"/>
        <source>About UDisks Plugin</source>
        <translation>O modulu UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="52"/>
        <source>Qmmp UDisks Plugin</source>
        <translation>Modul Qmmp UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using UDisks</source>
        <translation>Tento modul poskytuje detekci výměnných médií pomocí UDisks</translation>
    </message>
    <message>
        <location filename="../udisksfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UDisksPlugin</name>
    <message>
        <location filename="../udisksplugin.cpp" line="154"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Přidat CD „%1“</translation>
    </message>
    <message>
        <location filename="../udisksplugin.cpp" line="160"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Přidat svazek „%1“</translation>
    </message>
</context>
</TS>
